==> igniteui-angular-excel-16.1.0-beta.1.tgz: package/esm2015/lib/UltraCalcFunctionVLookup.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { UltraCalcFunctionLookupBase } from "./UltraCalcFunctionLookupBase";
import { ExcelCalcValue } from "./ExcelCalcValue";
import { ExcelCalcErrorValue } from "./ExcelCalcErrorValue";
import { markType } from "igniteui-angular-core";
import { truncate } from "igniteui-angular-core";
/**
 * @hidden
 */
export let UltraCalcFunctionVLookup = /*@__PURE__*/ (() => {
    class UltraCalcFunctionVLookup extends UltraCalcFunctionLookupBase {
        evaluate(a, b) {
            let c = null;
            if (b == 4) {
                c = a.pop();
            }
            let d = a.pop();
            let e = a.pop();
            let f = a.pop();
            if (f.isError) {
                return f;
            }
            if (e.isError) {
                return e;
            }
            if (d.isError) {
                return d;
            }
            if (c != null && c.isError) {
                return c;
            }
            if (f.isArray || f.isArrayGroup) {
                return new ExcelCalcValue(new ExcelCalcErrorValue(3));
            }
            if (f.isNull) {
                return new ExcelCalcValue(new ExcelCalcErrorValue(3));
            }
            let g = e._d(false);
            let h;
            if (((() => { let i = d._toDouble1(h); h = i.p0; return i.ret; })()) == false || h < 1) {
                return new ExcelCalcValue(new ExcelCalcErrorValue(1));
            }
            let i = truncate(Math.floor(h)) - 1;
            let j;
            if (((() => { let k = UltraCalcFunctionLookupBase._ak(c, j); j = k.p1; return k.ret; })()) == false) {
                return new ExcelCalcValue(new ExcelCalcErrorValue(1));
            }
            let k = g.getLength(1);
            let l = UltraCalcFunctionLookupBase._al(g._j(0, 0), f, j ? 1 : 0);
            if (l < 0 || k <= l) {
                return new ExcelCalcValue(new ExcelCalcErrorValue(3));
            }
            let m = g.getLength(0);
            if (m <= i) {
                return new ExcelCalcValue(new ExcelCalcErrorValue(0));
            }
            let n = g.item(i, l);
            n._z = true;
            return new ExcelCalcValue(n._getResolvedValue());
        }
        get_name() {
            return "vlookup";
        }
        get name() {
            return this.get_name();
        }
    }
    UltraCalcFunctionVLookup.$t = markType(UltraCalcFunctionVLookup, 'UltraCalcFunctionVLookup', UltraCalcFunctionLookupBase.$);
    return UltraCalcFunctionVLookup;
})();

==> igniteui-angular-excel-18.2.0-beta.1.tgz: package/esm2015/lib/UltraCalcFunctionVLookup.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { UltraCalcFunctionLookupBase } from "./UltraCalcFunctionLookupBase";
import { ExcelCalcValue } from "./ExcelCalcValue";
import { RegionArrayProxyBase } from "./RegionArrayProxyBase";
import { ExcelCalcErrorValue } from "./ExcelCalcErrorValue";
import { typeCast, markType } from "igniteui-angular-core";
import { truncate } from "igniteui-angular-core";
/**
 * @hidden
 */
export let UltraCalcFunctionVLookup = /*@__PURE__*/ (() => {
    class UltraCalcFunctionVLookup extends UltraCalcFunctionLookupBase {
        evaluate(a, b) {
            let c = null;
            if (b == 4) {
                c = a.pop();
            }
            let d = a.pop();
            let e = a.pop();
            let f = a.pop();
            if (f.isError) {
                return f;
            }
            if (e.isError) {
                return e;
            }
            if (d.isError) {
                return d;
            }
            if (c != null && c.isError) {
                return c;
            }
            if (f.isArray || f.isArrayGroup) {
                return new ExcelCalcValue(new ExcelCalcErrorValue(3));
            }
            if (f.isNull) {
                return new ExcelCalcValue(new ExcelCalcErrorValue(3));
            }
            let g = e._d(false);
            let h;
            if (((() => { let i = d._toDouble1(h); h = i.p0; return i.ret; })()) == false || h < 1) {
                return new ExcelCalcValue(new ExcelCalcErrorValue(1));
            }
            let i = truncate(Math.floor(h)) - 1;
            let j;
            if (((() => { let k = UltraCalcFunctionLookupBase._ak(c, j); j = k.p1; return k.ret; })()) == false) {
                return new ExcelCalcValue(new ExcelCalcErrorValue(1));
            }
            let k = g.getLength(1);
            if (typeCast(RegionArrayProxyBase.$, g) !== null) {
                let l = g._b(0, 0, k - 1, 0);
                let m = l;
                let n = m._s._c;
                a._p._addDynamicReference1(n, a._r._w, true);
            }
            let o = UltraCalcFunctionLookupBase._al(g._j(0, 0), f, j ? 1 : 0);
            if (o < 0 || k <= o) {
                return new ExcelCalcValue(new ExcelCalcErrorValue(3));
            }
            let p = g.getLength(0);
            if (p <= i) {
                return new ExcelCalcValue(new ExcelCalcErrorValue(0));
            }
            let q = g.item(i, o);
            q._ac = true;
            return new ExcelCalcValue(q._getResolvedValue());
        }
        get_name() {
            return "vlookup";
        }
        get name() {
            return this.get_name();
        }
    }
    UltraCalcFunctionVLookup.$t = markType(UltraCalcFunctionVLookup, 'UltraCalcFunctionVLookup', UltraCalcFunctionLookupBase.$);
    return UltraCalcFunctionVLookup;
})();
